@@ -48,6 +48,8 @@ class PyXploraApi(PyXplora):
                         # Try to login
                         try:
                             self._issueToken = self._gqlHandler.login()
+                        except LoginError as err:
+                            self.error_message = err.message
                         except Exception:
                             pass
 
@@ -75,7 +77,7 @@ class PyXploraApi(PyXplora):
                             self.watchs.append(watch)
                 self.user = token.get("user", {})
                 return
-        raise LoginError("Login to Xplora® API failed. Check your input!")
+        raise LoginError(self.error_message)
 
     def version(self) -> str:
         return "{0}-{1}".format(VERSION, VERSION_APP)
@@ -202,7 +204,6 @@ class PyXploraApi(PyXplora):
                     {},
                 )
                 if not _watchLastLocate:
-                    dataOk = {}
                     return watch_location
                 _tm = 31532399 if _watchLastLocate.get("tm") is None else _watchLastLocate.get("tm")
                 _lat = "0.0" if _watchLastLocate.get("lat") is None else _watchLastLocate.get("lat")
@@ -330,7 +331,7 @@ class PyXploraApi(PyXplora):
     def getWatchLastLocation(self, wuid: str, withAsk: bool = False) -> Dict[str, Any]:
         _loadWatchLocation = self.loadWatchLocation(wuid=wuid, withAsk=withAsk)
         if isinstance(_loadWatchLocation, dict):
-            return _loadWatchLocation.get("watch_last_location", {}) 
+            return _loadWatchLocation.get("watch_last_location", {})
         if not _loadWatchLocation:
             return {}
         for loadWatchLocation in _loadWatchLocation:
@@ -438,7 +439,6 @@ class PyXploraApi(PyXplora):
                 enable_raw = self._gqlHandler.setEnableSlientTime(silentId)
                 _setEnableSilentTime = enable_raw.get("setEnableSilentTime", -1)
                 if not _setEnableSilentTime:
-                    dataOk = "0"
                     return bool(_raw)
                 _raw = _setEnableSilentTime
             except Exception as error:
@@ -459,7 +459,6 @@ class PyXploraApi(PyXplora):
                 disable_raw = self._gqlHandler.setEnableSlientTime(silentId, NormalStatus.DISABLE.value)
                 _setEnableSilentTime = disable_raw.get("setEnableSilentTime", -1)
                 if not _setEnableSilentTime:
-                    dataOk = "0"
                     return bool(_raw)
                 _raw = _setEnableSilentTime
             except Exception as error:
@@ -492,7 +491,6 @@ class PyXploraApi(PyXplora):
                 enable_raw = self._gqlHandler.setEnableAlarmTime(alarmId)
                 _modifyAlarm = enable_raw.get("modifyAlarm", -1)
                 if not _modifyAlarm:
-                    dataOk = "0"
                     return bool(_raw)
                 _raw = _modifyAlarm
             except Exception as error:
@@ -513,7 +511,6 @@ class PyXploraApi(PyXplora):
                 disable_raw = self._gqlHandler.setEnableAlarmTime(alarmId, NormalStatus.DISABLE.value)
                 _modifyAlarm = disable_raw.get("modifyAlarm", -1)
                 if not _modifyAlarm:
-                    dataOk = "0"
                     return bool(_raw)
                 _raw = _modifyAlarm
             except Exception as error:
@@ -574,7 +571,6 @@ class PyXploraApi(PyXplora):
                 watches_raw = self._gqlHandler.getWatches(wuid)
                 _watches: List[Dict[str, Any]] = watches_raw.get("watches", [])
                 if not _watches:
-                    dataOk = {}
                     return watches
                 for watch in _watches:
                     watches = {
